@@ -115,6 +115,9 @@ typedef struct {
 
 static EmpathyMainWindow *window = NULL;
 
+static gboolean main_window_configure_event_timeout_cb (
+    EmpathyMainWindow *window);
+
 static void
 main_window_flash_stop (EmpathyMainWindow *window)
 {
@@ -647,6 +650,7 @@ main_window_destroy_cb (GtkWidget         *widget,
 
 	if (window->size_timeout_id) {
 		g_source_remove (window->size_timeout_id);
+		main_window_configure_event_timeout_cb (window);
 	}
 
 	g_list_free (window->actions_connected);
